@@ -3,12 +3,7 @@ import re
 from sqlalchemy.orm import aliased
 from sqlalchemy.exc import IntegrityError, StatementError
 
-from zou.app.utils import (
-    cache,
-    events,
-    fields,
-    query as query_utils
-)
+from zou.app.utils import cache, events, fields, query as query_utils
 
 from zou.app.models.entity import Entity, EntityLink, EntityVersion
 from zou.app.models.project import Project
@@ -16,7 +11,6 @@ from zou.app.models.schedule_item import ScheduleItem
 from zou.app.models.subscription import Subscription
 from zou.app.models.task import Task
 from zou.app.models.task import assignees_table
-from zou.app.models.task_status import TaskStatus
 
 from zou.app.services import (
     deletion_service,
@@ -41,6 +35,15 @@ def clear_shot_cache(shot_id):
     cache.cache.delete_memoized(get_full_shot, shot_id)
 
 
+def clear_sequence_cache(sequence_id):
+    cache.cache.delete_memoized(get_sequence, sequence_id)
+    cache.cache.delete_memoized(get_full_sequence, sequence_id)
+
+
+def clear_episode_cache(episode_id):
+    cache.cache.delete_memoized(get_episode, episode_id)
+
+
 def get_temporal_entity_type_by_name(name):
     entity_type = entities_service.get_entity_type_by_name(name)
     if entity_type is None:
@@ -278,48 +281,52 @@ def get_shots_and_tasks(criterions={}):
 
         if shot_id not in shot_map:
 
-            shot_map[shot_id] = fields.serialize_dict({
-                "canceled": shot.canceled,
-                "data": shot.data,
-                "description": shot.description,
-                "entity_type_id": shot.entity_type_id,
-                "episode_id": episode_id,
-                "episode_name": episode_name or "",
-                "fps": shot.data.get("fps", None),
-                "frame_in": shot.data.get("frame_in", None),
-                "frame_out": shot.data.get("frame_out", None),
-                "id": shot.id,
-                "name": shot.name,
-                "nb_frames": shot.nb_frames,
-                "parent_id": shot.parent_id,
-                "preview_file_id": shot.preview_file_id or None,
-                "project_id": project_id,
-                "project_name": project_name,
-                "sequence_id": sequence_id,
-                "sequence_name": sequence_name,
-                "source_id": shot.source_id,
-                "tasks": [],
-                "type": "Shot",
-            })
+            shot_map[shot_id] = fields.serialize_dict(
+                {
+                    "canceled": shot.canceled,
+                    "data": shot.data,
+                    "description": shot.description,
+                    "entity_type_id": shot.entity_type_id,
+                    "episode_id": episode_id,
+                    "episode_name": episode_name or "",
+                    "fps": shot.data.get("fps", None),
+                    "frame_in": shot.data.get("frame_in", None),
+                    "frame_out": shot.data.get("frame_out", None),
+                    "id": shot.id,
+                    "name": shot.name,
+                    "nb_frames": shot.nb_frames,
+                    "parent_id": shot.parent_id,
+                    "preview_file_id": shot.preview_file_id or None,
+                    "project_id": project_id,
+                    "project_name": project_name,
+                    "sequence_id": sequence_id,
+                    "sequence_name": sequence_name,
+                    "source_id": shot.source_id,
+                    "tasks": [],
+                    "type": "Shot",
+                }
+            )
 
         if task_id is not None:
             if task_id not in task_map:
-                task_dict = fields.serialize_dict({
-                    "id": task_id,
-                    "entity_id": shot_id,
-                    "task_status_id": task_status_id,
-                    "task_type_id": task_type_id,
-                    "priority": task_priority or 0,
-                    "estimation": task_estimation,
-                    "duration": task_duration,
-                    "retake_count": task_retake_count,
-                    "real_start_date": task_real_start_date,
-                    "end_date": task_end_date,
-                    "start_date": task_start_date,
-                    "due_date": task_due_date,
-                    "last_comment_date": task_last_comment_date,
-                    "assignees": [],
-                })
+                task_dict = fields.serialize_dict(
+                    {
+                        "id": task_id,
+                        "entity_id": shot_id,
+                        "task_status_id": task_status_id,
+                        "task_type_id": task_type_id,
+                        "priority": task_priority or 0,
+                        "estimation": task_estimation,
+                        "duration": task_duration,
+                        "retake_count": task_retake_count,
+                        "real_start_date": task_real_start_date,
+                        "end_date": task_end_date,
+                        "start_date": task_start_date,
+                        "due_date": task_due_date,
+                        "last_comment_date": task_last_comment_date,
+                        "assignees": [],
+                    }
+                )
                 task_map[task_id] = task_dict
                 shot_dict = shot_map[shot_id]
                 shot_dict["tasks"].append(task_dict)
@@ -435,6 +442,7 @@ def get_sequence_raw(sequence_id):
     return sequence
 
 
+@cache.memoize_function(120)
 def get_sequence(sequence_id):
     """
     Return given sequence as a dictionary.
@@ -442,6 +450,7 @@ def get_sequence(sequence_id):
     return get_sequence_raw(sequence_id).serialize(obj_type="Sequence")
 
 
+@cache.memoize_function(120)
 def get_full_sequence(sequence_id):
     """
     Return given sequence as a dictionary with extra data like project name.
@@ -489,6 +498,7 @@ def get_episode_raw(episode_id):
     return episode
 
 
+@cache.memoize_function(120)
 def get_episode(episode_id):
     """
     Return given episode as a dictionary.
@@ -665,8 +675,7 @@ def get_episodes_for_project(project_id, only_assigned=False):
         Shot = aliased(Entity, name="shot")
         Asset = aliased(Entity, name="asset")
         query = (
-            Entity.query
-            .join(Sequence, Entity.id == Sequence.parent_id)
+            Entity.query.join(Sequence, Entity.id == Sequence.parent_id)
             .join(Shot, Sequence.id == Shot.parent_id)
             .join(Task, Shot.id == Task.entity_id)
             .filter(Entity.project_id == project_id)
@@ -675,8 +684,7 @@ def get_episodes_for_project(project_id, only_assigned=False):
         shot_episodes = fields.serialize_models(query.all())
         shot_episode_ids = {episode["id"]: True for episode in shot_episodes}
         query = (
-            Entity.query
-            .join(Asset, Entity.id == Asset.source_id)
+            Entity.query.join(Asset, Entity.id == Asset.source_id)
             .join(Task, Asset.id == Task.entity_id)
             .filter(Entity.project_id == project_id)
             .filter(user_service.build_assignee_filter())
@@ -700,8 +708,7 @@ def get_sequences_for_project(project_id, only_assigned=False):
     if only_assigned:
         Shot = aliased(Entity, name="shot")
         query = (
-            Entity.query
-            .join(Shot, Entity.id == Shot.parent_id)
+            Entity.query.join(Shot, Entity.id == Shot.parent_id)
             .join(Task, Shot.id == Task.entity_id)
             .filter(Entity.project_id == project_id)
             .filter(user_service.build_assignee_filter())
@@ -720,8 +727,7 @@ def get_sequences_for_episode(episode_id, only_assigned=False):
     if only_assigned:
         Shot = aliased(Entity, name="shot")
         query = (
-            Entity.query
-            .join(Shot, Entity.id == Shot.parent_id)
+            Entity.query.join(Shot, Entity.id == Shot.parent_id)
             .join(Task, Shot.id == Task.entity_id)
             .filter(Entity.parent_id == episode_id)
             .filter(user_service.build_assignee_filter())
@@ -747,8 +753,7 @@ def get_shots_for_episode(episode_id, relations=False):
     Sequence = aliased(Entity, name="sequence")
     shot_type_id = get_shot_type()["id"]
     result = (
-        Entity.query
-        .filter(Entity.entity_type_id == shot_type_id)
+        Entity.query.filter(Entity.entity_type_id == shot_type_id)
         .filter(Sequence.parent_id == episode_id)
         .join(Sequence, Entity.parent_id == Sequence.id)
     ).all()
@@ -791,9 +796,7 @@ def remove_shot(shot_id, force=False):
         shot.update({"canceled": True})
         clear_shot_cache(shot_id)
         events.emit(
-            "shot:update",
-            {"shot_id": shot_id},
-            project_id=str(shot.project_id)
+            "shot:update", {"shot_id": shot_id}, project_id=str(shot.project_id)
         )
     else:
         from zou.app.services import tasks_service
@@ -811,9 +814,7 @@ def remove_shot(shot_id, force=False):
         shot.delete()
         clear_shot_cache(shot_id)
         events.emit(
-            "shot:delete",
-            {"shot_id": shot_id},
-            project_id=str(shot.project_id)
+            "shot:delete", {"shot_id": shot_id}, project_id=str(shot.project_id)
         )
 
     deleted_shot = shot.serialize(obj_type="Shot")
@@ -832,9 +833,7 @@ def remove_scene(scene_id):
         scene.update({"canceled": True})
     deleted_scene = scene.serialize(obj_type="Scene")
     events.emit(
-        "scene:delete",
-        {"scene_id": scene_id},
-        project_id=str(scene.project_id)
+        "scene:delete", {"scene_id": scene_id}, project_id=str(scene.project_id)
     )
     return deleted_scene
 
@@ -855,6 +854,7 @@ def remove_sequence(sequence_id, force=False):
         raise ModelWithRelationsDeletionException(
             "Some data are still linked to this sequence."
         )
+    clear_sequence_cache(sequence_id)
     return sequence.serialize(obj_type="Sequence")
 
 
@@ -929,10 +929,14 @@ def create_shot(project_id, sequence_id, name, data={}, nb_frames=0):
             data=data,
             nb_frames=nb_frames,
         )
-    events.emit("shot:new", {
-        "shot_id": shot.id,
-        "episode_id": sequence["parent_id"],
-    }, project_id=project_id)
+    events.emit(
+        "shot:new",
+        {
+            "shot_id": shot.id,
+            "episode_id": sequence["parent_id"],
+        },
+        project_id=project_id,
+    )
     return shot.serialize(obj_type="Shot")
 
 
@@ -974,39 +978,11 @@ def update_shot(shot_id, data_dict):
     shot.update(data_dict)
     clear_shot_cache(shot_id)
     events.emit(
-        "shot:update",
-        {"shot_id": shot_id},
-        project_id=str(shot.project_id)
+        "shot:update", {"shot_id": shot_id}, project_id=str(shot.project_id)
     )
     return shot.serialize()
 
 
-def get_preview_dimensions(project):
-    """
-    Return dimensions set at project level or default dimensions if the
-    dimensions are not set.
-    """
-    resolution = project["resolution"]
-    height = 1080
-    width = None
-    if resolution is not None and bool(re.match(r"\d*x\d*", resolution)):
-        [width, height] = resolution.split("x")
-        width = int(width)
-        height = int(height)
-    return (width, height)
-
-
-def get_preview_fps(project):
-    """
-    Return fps set at project level or default fps if the dimensions are not
-    set.
-    """
-    fps = "24.00"
-    if project["fps"] is not None:
-        fps = "%.2f" % float(project["fps"].replace(",", "."))
-    return fps
-
-
 def get_shot_versions(shot_id):
     """
     Shot metadata changes are versioned. This function returns all versions
