@@ -13,7 +13,7 @@ from zou.app.models.comment import (
     Comment,
     acknowledgements_table,
     mentions_table,
-    preview_link_table
+    preview_link_table,
 )
 from zou.app.models.department import Department
 from zou.app.models.entity import Entity
@@ -60,6 +60,11 @@ def clear_task_type_cache(task_type_id):
     cache.cache.delete_memoized(get_task_types)
 
 
+def clear_department_cache(department_id):
+    cache.cache.delete_memoized(get_department, department_id)
+    cache.cache.delete_memoized(get_departments)
+
+
 def clear_task_cache(task_id):
     cache.cache.delete_memoized(get_task, task_id)
     cache.cache.delete_memoized(get_task_with_relations, task_id)
@@ -72,6 +77,11 @@ def clear_comment_cache(comment_id):
     cache.cache.delete_memoized(get_comment_with_relations, comment_id)
 
 
+@cache.memoize_function(120)
+def get_departments():
+    return fields.serialize_models(Department.get_all())
+
+
 @cache.memoize_function(120)
 def get_task_types():
     return fields.serialize_models(TaskType.get_all())
@@ -121,10 +131,12 @@ def get_task_status(task_status_id):
     return get_task_status_raw(task_status_id).serialize()
 
 
+@cache.memoize_function(120)
 def get_department(department_id):
     """
     Get department matching given id as a dictionary.
     """
+    print(department_id)
     try:
         department = Department.get(department_id)
     except StatementError:
@@ -264,10 +276,8 @@ def get_shot_tasks_for_episode(episode_id, relations=False):
     """
     query = _get_entity_task_query()
     Sequence = aliased(Entity, name="sequence")
-    query = (
-        query
-        .join(Sequence, Entity.parent_id == Sequence.id)
-        .filter(Sequence.parent_id == episode_id)
+    query = query.join(Sequence, Entity.parent_id == Sequence.id).filter(
+        Sequence.parent_id == episode_id
     )
     return _convert_rows_to_detailed_tasks(query.all(), relations)
 
@@ -339,6 +349,16 @@ def get_task_types_for_sequence(sequence_id):
     """
     Return all task types for which there is a task related to given sequence.
     """
+    Sequence = aliased(Entity, name="sequence")
+    task_types = (
+        TaskType.query.join(Task, Entity)
+        .join(Sequence, Sequence.id == Entity.parent_id)
+        .filter(Sequence.id == sequence_id)
+        .group_by(TaskType.id)
+        .all()
+    )
+    return fields.serialize_models(task_types)
+
     return get_task_types_for_entity(sequence_id)
 
 
@@ -353,7 +373,17 @@ def get_task_types_for_episode(episode_id):
     """
     Return all task types for which there is a task related to given episode.
     """
-    return get_task_types_for_entity(episode_id)
+    Sequence = aliased(Entity, name="sequence")
+    Episode = aliased(Entity, name="episode")
+    task_types = (
+        TaskType.query.join(Task, Entity)
+        .join(Sequence, Sequence.id == Entity.parent_id)
+        .join(Episode, Episode.id == Sequence.parent_id)
+        .filter(Episode.id == episode_id)
+        .group_by(TaskType.id)
+        .all()
+    )
+    return fields.serialize_models(task_types)
 
 
 def get_task_types_for_entity(entity_id):
@@ -408,34 +438,12 @@ def get_next_position(task_id, revision):
     """
     Get upcoming position for preview files of given task and revision.
     """
-    preview_files = (
-        PreviewFile.query.filter_by(task_id=task_id, revision=revision)
-        .all()
-    )
+    preview_files = PreviewFile.query.filter_by(
+        task_id=task_id, revision=revision
+    ).all()
     return len(preview_files) + 1
 
 
-def update_preview_file_position(preview_file_id, position):
-    """
-    Change positions for preview files of given task and revision.
-    Given position is the new position for given preview file. :q
-    """
-    preview_file = files_service.get_preview_file_raw(preview_file_id)
-    task_id = preview_file.task_id
-    revision = preview_file.revision
-    preview_files = (
-        PreviewFile.query.filter_by(task_id=task_id, revision=revision)
-        .order_by(PreviewFile.position, PreviewFile.created_at)
-        .all()
-    )
-    if position > 0 and position <= len(preview_files):
-        tmp_list = [p for p in preview_files if str(p.id) != preview_file_id]
-        tmp_list.insert(position - 1, preview_file)
-        for (i, preview) in enumerate(tmp_list):
-            preview.update({"position": i + 1})
-    return PreviewFile.serialize_list(preview_files)
-
-
 def get_time_spents(task_id):
     """
     Return time spents for given task.
@@ -465,15 +473,15 @@ def get_comments(task_id, is_client=False, is_manager=False):
             comment["acknowledgements"] = ack_map.get(comment["id"], [])
             comment["previews"] = preview_map.get(comment["id"], [])
             comment["mentions"] = mention_map.get(comment["id"], [])
-            comment["attachment_files"] = \
-                attachment_file_map.get(comment["id"], [])
+            comment["attachment_files"] = attachment_file_map.get(
+                comment["id"], []
+            )
     return comments
 
 
 def _prepare_query(task_id, is_client, is_manager):
     query = (
-        Comment.query
-        .order_by(Comment.created_at.desc())
+        Comment.query.order_by(Comment.created_at.desc())
         .filter_by(object_id=task_id)
         .join(Person, TaskStatus)
         .add_columns(
@@ -527,8 +535,7 @@ def _run_task_comments_query(query):
 def _build_ack_map_for_comments(comment_ids):
     ack_map = {}
     for link in (
-        db.session
-        .query(acknowledgements_table)
+        db.session.query(acknowledgements_table)
         .filter(acknowledgements_table.c.comment.in_(comment_ids))
         .all()
     ):
@@ -543,8 +550,7 @@ def _build_ack_map_for_comments(comment_ids):
 def _build_mention_map_for_comments(comment_ids):
     mention_map = {}
     for link in (
-        db.session
-        .query(mentions_table)
+        db.session.query(mentions_table)
         .filter(mentions_table.c.comment.in_(comment_ids))
         .all()
     ):
@@ -559,8 +565,7 @@ def _build_mention_map_for_comments(comment_ids):
 def _build_preview_map_for_comments(comment_ids):
     preview_map = {}
     query = (
-        PreviewFile.query
-        .join(preview_link_table)
+        PreviewFile.query.join(preview_link_table)
         .filter(preview_link_table.c.comment.in_(comment_ids))
         .add_columns(preview_link_table.c.comment)
     )
@@ -568,36 +573,43 @@ def _build_preview_map_for_comments(comment_ids):
         comment_id = str(comment_id)
         if comment_id not in preview_map:
             preview_map[comment_id] = []
-        preview_map[comment_id].append({
-            "id": str(preview.id),
-            "task_id": str(preview.task_id),
-            "revision": preview.revision,
-            "extension": preview.extension,
-            "original_name": preview.original_name,
-            "position": preview.position,
-            "annotations": preview.annotations,
-        })
+        status = "ready"
+        if preview.status is not None:
+            status = preview.status.code
+
+        preview_map[comment_id].append(
+            {
+                "id": str(preview.id),
+                "task_id": str(preview.task_id),
+                "revision": preview.revision,
+                "extension": preview.extension,
+                "status": status,
+                "original_name": preview.original_name,
+                "position": preview.position,
+                "annotations": preview.annotations,
+            }
+        )
     return preview_map
 
 
 def _build_attachment_map_for_comments(comment_ids):
     attachment_file_map = {}
-    attachment_files = (
-        AttachmentFile.query
-        .filter(AttachmentFile.comment_id.in_(comment_ids))
-        .all()
-    )
+    attachment_files = AttachmentFile.query.filter(
+        AttachmentFile.comment_id.in_(comment_ids)
+    ).all()
     for attachment_file in attachment_files:
         comment_id = str(attachment_file.comment_id)
         attachment_file_id = str(attachment_file.id)
         if comment_id not in attachment_file_map:
             attachment_file_map[str(comment_id)] = []
-        attachment_file_map[str(comment_id)].append({
-            "id": attachment_file_id,
-            "name": attachment_file.name,
-            "extension": attachment_file.extension,
-            "size": attachment_file.size
-        })
+        attachment_file_map[str(comment_id)].append(
+            {
+                "id": attachment_file_id,
+                "name": attachment_file.name,
+                "extension": attachment_file.extension,
+                "size": attachment_file.size,
+            }
+        )
     return attachment_file_map
 
 
@@ -676,6 +688,32 @@ def get_person_done_tasks(person_id, projects):
     return get_person_tasks(person_id, projects, is_done=True)
 
 
+def get_person_related_tasks(person_id, task_type_id):
+    """
+    Retrieve all tasks for given task types and to entiities
+    that have at least one person assignation.
+    """
+    person = Person.get(person_id)
+    projects = projects_service.open_projects()
+    project_ids = [project["id"] for project in projects]
+
+    AssignedTask = aliased(Entity, name="sequence")
+    entities = (
+        Entity.query.join(Task, Entity.id == Task.entity_id)
+        .filter(Task.assignees.contains(person))
+        .filter(Entity.project_id.in_(project_ids))
+    ).all()
+
+    entity_ids = [entity.id for entity in entities]
+    tasks = (
+        Task.query.filter(Task.entity_id.in_(entity_ids)).filter(
+            Task.task_type_id == task_type_id
+        )
+    ).all()
+
+    return fields.serialize_models(tasks)
+
+
 def get_person_tasks(person_id, projects, is_done=None):
     """
     Retrieve all tasks for given person and projects.
@@ -777,7 +815,16 @@ def get_person_tasks(person_id, projects, is_done=None):
         tasks.append(task_dict)
 
     task_ids = [task["id"] for task in tasks]
+    task_comment_map = get_last_comment_map(task_ids)
+    for task in tasks:
+        if task["id"] in task_comment_map:
+            task["last_comment"] = task_comment_map[task["id"]]
+        else:
+            task["last_comment"] = {}
+    return tasks
 
+
+def get_last_comment_map(task_ids):
     task_comment_map = {}
     comments = (
         Comment.query.filter(Comment.object_id.in_(task_ids))
@@ -786,7 +833,6 @@ def get_person_tasks(person_id, projects, is_done=None):
         .order_by(Comment.object_id, Comment.created_at)
         .all()
     )
-
     task_id = None
     for comment in comments:
         if comment.object_id != task_id:
@@ -796,13 +842,7 @@ def get_person_tasks(person_id, projects, is_done=None):
                 "date": fields.serialize_value(comment.created_at),
                 "person_id": fields.serialize_value(comment.person_id),
             }
-    for task in tasks:
-        if task["id"] in task_comment_map:
-            task["last_comment"] = task_comment_map[task["id"]]
-        else:
-            task["last_comment"] = {}
-
-    return tasks
+    return task_comment_map
 
 
 def create_tasks(task_type, entities):
@@ -818,12 +858,9 @@ def create_tasks(task_type, entities):
 
     tasks = []
     for entity in entities:
-        existing_task = Task.query \
-            .filter_by(
-                entity_id=entity["id"],
-                task_type_id=task_type["id"]
-            ) \
-            .scalar()
+        existing_task = Task.query.filter_by(
+            entity_id=entity["id"], task_type_id=task_type["id"]
+        ).scalar()
         if existing_task is None:
             task = Task.create_no_commit(
                 name="main",
@@ -902,9 +939,7 @@ def _finalize_task_creation(task_type, task_status, task):
         }
     )
     events.emit(
-        "task:new",
-        {"task_id": task.id},
-        project_id=task_dict["project_id"]
+        "task:new", {"task_id": task.id}, project_id=task_dict["project_id"]
     )
     return task_dict
 
@@ -921,9 +956,7 @@ def update_task(task_id, data):
     task.update(data)
     clear_task_cache(task_id)
     events.emit(
-        "task:update",
-        {"task_id": task_id},
-        project_id=str(task.project_id)
+        "task:update", {"task_id": task_id}, project_id=str(task.project_id)
     )
     return task.serialize()
 
@@ -972,6 +1005,7 @@ def get_or_create_department(name):
     if department is None:
         department = Department(name=name, color="#000000")
         department.save()
+        clear_department_cache(department.id)
         events.emit("department:new", {"department_id": department.id})
     return department.serialize()
 
@@ -1029,7 +1063,7 @@ def create_or_update_time_spent(task_id, person_id, date, duration, add=False):
         events.emit(
             "time-spent:update",
             {"time_spent_id": str(time_spent.id)},
-            project_id=project_id
+            project_id=project_id,
         )
     else:
         time_spent = TimeSpent.create(
@@ -1038,20 +1072,16 @@ def create_or_update_time_spent(task_id, person_id, date, duration, add=False):
         events.emit(
             "time-spent:new",
             {"time_spent_id": str(time_spent.id)},
-            project_id=project_id
+            project_id=project_id,
         )
 
     task.duration = 0
     time_spents = TimeSpent.get_all_by(task_id=task_id)
-    for time_spent in time_spents:
-        task.duration += time_spent.duration
+    for task_time_spent in time_spents:
+        task.duration += task_time_spent.duration
     task.save()
     clear_task_cache(task_id)
-    events.emit(
-        "task:update",
-        {"task_id": task_id},
-        project_id=project_id
-    )
+    events.emit("task:update", {"task_id": task_id}, project_id=project_id)
 
     return time_spent.serialize()
 
@@ -1085,7 +1115,7 @@ def clear_assignation(task_id):
         events.emit(
             "task:unassign",
             {"person_id": assignee["id"], "task_id": task_id},
-            project_id=project_id
+            project_id=project_id,
         )
     events.emit("task:update", {"task_id": task_id}, project_id=project_id)
     return task_dict
@@ -1107,7 +1137,7 @@ def assign_task(task_id, person_id):
     events.emit(
         "task:assign",
         {"task_id": task.id, "person_id": person.id},
-        project_id=project_id
+        project_id=project_id,
     )
     clear_task_cache(task_id)
     events.emit("task:update", {"task_id": task_id}, project_id=project_id)
@@ -1142,7 +1172,7 @@ def start_task(task_id):
                 "previous_task_status_id": task_dict_before["task_status_id"],
                 "real_start_date": task.real_start_date,
                 "shotgun_id": task_dict_before["shotgun_id"],
-            }
+            },
         )
 
     return task.serialize()
@@ -1222,16 +1252,14 @@ def add_preview_file_to_comment(comment_id, person_id, task_id, revision=0):
             "preview_file_id": preview_file.id,
             "comment_id": comment_id,
         },
-        project_id=project_id
+        project_id=project_id,
     )
     comment.previews.append(preview_file)
     comment.save()
     if news is not None:
         news.update({"preview_file_id": preview_file.id})
     events.emit(
-        "comment:update",
-        {"comment_id": comment.id},
-        project_id=project_id
+        "comment:update", {"comment_id": comment.id}, project_id=project_id
     )
     return preview_file.serialize()
 
