@@ -364,9 +364,7 @@ def check_entity_access(entity_id):
     is_allowed = not permissions.has_vendor_permissions()
     if not is_allowed:
         nb_tasks = (
-            Task
-            .query
-            .filter(Task.entity_id == entity_id)
+            Task.query.filter(Task.entity_id == entity_id)
             .filter(build_assignee_filter())
             .count()
         )
@@ -381,11 +379,9 @@ def check_manager_project_access(project_id):
     Return true if current user is manager or has a task assigned for this
     project.
     """
-    is_allowed = (
-        permissions.has_admin_permissions() or (
-            permissions.has_manager_permissions() and
-            check_belong_to_project(project_id)
-        )
+    is_allowed = permissions.has_admin_permissions() or (
+        permissions.has_manager_permissions()
+        and check_belong_to_project(project_id)
     )
     if not is_allowed:
         raise permissions.PermissionDenied
@@ -515,7 +511,17 @@ def get_notification(notification_id):
     return notifications[0]
 
 
-def get_last_notifications(notification_id=None):
+def get_unread_notifications_count(notification_id=None):
+    """
+    Return the number of unread notifications.
+    """
+    current_user = persons_service.get_current_user()
+    return Notification.query.filter_by(
+        person_id=current_user["id"], read=False
+    ).count()
+
+
+def get_last_notifications(notification_id=None, after=None, before=None):
     """
     Return last 100 user notifications.
     """
@@ -540,6 +546,12 @@ def get_last_notifications(notification_id=None):
     if notification_id is not None:
         query = query.filter(Notification.id == notification_id)
 
+    if after is not None:
+        query = query.filter(Notification.created_at > after)
+
+    if before is not None:
+        query = query.filter(Notification.created_at < before)
+
     notifications = query.limit(100).all()
 
     for (
@@ -681,6 +693,14 @@ def get_sequence_subscriptions(project_id, task_type_id):
     )
 
 
+def get_timezone():
+    try:
+        timezone = persons_service.get_current_user()["timezone"]
+    except:
+        timezone = "Europe/Paris"
+    return timezone or "Europe/Paris"
+
+
 def get_context():
     if permissions.has_admin_permissions():
         projects = projects_service.open_projects()
@@ -692,8 +712,9 @@ def get_context():
     persons = persons_service.get_persons(
         minimal=not permissions.has_manager_permissions()
     )
-    notifications = get_last_notifications()
+    notification_count = get_unread_notifications_count()
     project_status_list = projects_service.get_project_statuses()
+    departments = tasks_service.get_departments()
     task_types = tasks_service.get_task_types()
     task_status_list = tasks_service.get_task_statuses()
     search_filters = get_filters()
@@ -701,7 +722,8 @@ def get_context():
     return {
         "asset_types": asset_types,
         "custom_actions": custom_actions,
-        "notifications": notifications,
+        "departments": departments,
+        "notification_count": notification_count,
         "persons": persons,
         "project_status": project_status_list,
         "projects": projects,
